Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(301)

Unified Diff: ios/web/public/test/earl_grey/web_view_matchers.h

Issue 1950323002: Refactor web shell integration tests utilities. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: alphabetize Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/web/public/test/earl_grey/web_view_matchers.h
diff --git a/ios/web/shell/test/web_view_matchers.h b/ios/web/public/test/earl_grey/web_view_matchers.h
similarity index 57%
rename from ios/web/shell/test/web_view_matchers.h
rename to ios/web/public/test/earl_grey/web_view_matchers.h
index 0ba394e44b114a81108f77f671b878c52940f9e6..397b45a78c1c2310bbc9ab40980e30d37c7a3196 100644
--- a/ios/web/shell/test/web_view_matchers.h
+++ b/ios/web/public/test/earl_grey/web_view_matchers.h
@@ -4,16 +4,19 @@
#import <EarlGrey/EarlGrey.h>
+#include "ios/web/public/web_state/web_state.h"
+
namespace web {
-// Shorthand for GREYMatchers::matcherForWebViewContainingText.
-id<GREYMatcher> webViewContainingText(NSString* text);
+// Shorthand for GREYMatchers::matcherForWebViewContainingText:inWebState.
+id<GREYMatcher> webViewContainingText(NSString* text, web::WebState* webState);
} // namespace web
@interface GREYMatchers (WebViewAdditions)
// Matcher for WKWebView containing |text|.
-+ (id<GREYMatcher>)matcherForWebViewContainingText:(NSString*)text;
++ (id<GREYMatcher>)matcherForWebViewContainingText:(NSString*)text
+ inWebState:(web::WebState*)webState;
-@end
+@end

Powered by Google App Engine
This is Rietveld 408576698